@@ -18,6 +18,10 @@ class Node:
         self.continueOnError = False
         self.scope = ''
 
+    def get_var_name(self, var):
+        d = {v:k for k,v in globals().items()}
+        return d[var]
+
     def on_create(self):
         pass
 
@@ -61,17 +65,18 @@ class NodeServicer(plugin_pb2_grpc.NodeServicer):
 
     def OnMessage(self, request: plugin_pb2.OnMessageRequest, context):
         node = Runtime.nodes[request.guid]
-
         try:
             data = Runtime.decompress(request.inMessage)
+            
 
             if request.guid in Runtime.nodes:
+                
                 ctx = Message(data)
                 node.on_message(ctx)
-
                 out_message = ctx.get_raw()
+                return plugin_pb2.OnMessageResponse(outMessage=out_message)
 
-            return plugin_pb2.OnMessageResponse(outMessage=out_message)
+            return plugin_pb2.OnMessageResponse(outMessage=data)
 
         except Exception as e:
             if node.continueOnError:
@@ -80,7 +85,8 @@ class NodeServicer(plugin_pb2_grpc.NodeServicer):
             if isinstance(e, Error):
                 raise grpc.RpcError(grpc.Status(grpc.StatusCode.UNKNOWN, e.serialize()))
 
-            raise grpc.RpcError(grpc.Status(grpc.StatusCode.UNKNOWN, Error('Err.Unknown', str(e)).serialize()))
+            raise e
+            #raise grpc.RpcError(grpc.Status(grpc.StatusCode.UNKNOWN, Error('Err.Unknown', str(e)).serialize()))
 
     def OnClose(self, request: plugin_pb2.OnCloseRequest, context):
         try:
