@@ -12,6 +12,7 @@ from robomotion.factory import NodeFactory
 from robomotion.node import NodeServicer, Node
 from robomotion.runtime import Runtime
 from robomotion.spec import Spec
+from robomotion.debug import Debug
 
 
 async def start():
@@ -34,8 +35,16 @@ async def start():
 
     print("1|1|tcp|127.0.0.1:%d|grpc\n" % port, flush=True)
 
+    ns = ''
+    if len(sys.argv) > 2 and sys.argv[1] == '-a':
+        ns = sys.argv[2]
+        Debug.attach('127.0.0.1:%d'%port, ns)
+
     Runtime.event.wait()
 
+    if ns != '':
+        Debug.detach(ns)
+
 
 def init():
     frm = inspect.stack()[2]
