@@ -4,7 +4,7 @@ from google.protobuf import json_format
 from robomotion.struct_pb2 import Struct
 from robomotion.message import Context
 import json
-import enum
+from enum import IntEnum
 
 
 class _DefVal:
@@ -121,7 +121,7 @@ class OptVariable(Variable):
         return Runtime.get_variable(self, ctx)
 
 
-class ECategory(enum.Enum):
+class ECategory(IntEnum):
     Null = 0,
     Login = 1
     Email = 2
